<?php

namespace Btravel\Toppartners\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Toppartners\Http\Requests\ToppartnerRequest;
use Btravel\Toppartners\Interfaces\ToppartnerRepositoryInterface;
use Btravel\Toppartners\Models\Toppartner;
use Btravel\Toppartners\Forms\Toppartner as Form;

/**
 * APIController  class for toppartner.
 */
class ToppartnerAPIController extends BaseController
{

    /**
     * Initialize toppartner resource controller.
     *
     * @param type ToppartnerRepositoryInterface $toppartner
     *
     * @return null
     */
    public function __construct(ToppartnerRepositoryInterface $toppartner)
    {
        parent::__construct();
        $this->repository = $toppartner;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Toppartners\Repositories\Criteria\ToppartnerResourceCriteria::class);
    }

    /**
     * Display a list of toppartner.
     *
     * @return Response
     */
    public function index(ToppartnerRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Toppartners\Repositories\Presenter\ToppartnerPresenter::class)
            ->paginate();
    }

    /**
     * Display toppartner.
     *
     * @param Request $request
     * @param Model   $toppartner
     *
     * @return Response
     */
    public function show(ToppartnerRequest $request, Toppartner $toppartner)
    {
        return $toppartner->setPresenter(\Btravel\Toppartners\Repositories\Presenter\ToppartnerListPresenter::class);
        ;
    }

    /**
     * Create new toppartner.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ToppartnerRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('toppartners::toppartner.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('toppartners/toppartner/' . $toppartner->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('toppartners/toppartner');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the toppartner.
     *
     * @param Request $request
     * @param Model   $toppartner
     *
     * @return Response
     */
    public function update(ToppartnerRequest $request, Toppartner $toppartner)
    {
        try {
            $data = $request->all();

            $toppartner->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('toppartners::toppartner.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('toppartners/toppartner/' . $toppartner->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('toppartners/toppartner/' . $toppartner->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the toppartner.
     *
     * @param Model   $toppartner
     *
     * @return Response
     */
    public function destroy(ToppartnerRequest $request, Toppartner $toppartner)
    {
        try {
            $toppartner->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('toppartners::toppartner.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('toppartners/toppartner/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('toppartners/toppartner/' . $toppartner->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
