<?php

namespace Btravel\Toppartner\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Toppartner\Models\Toppartner;

class ToppartnerPolicy
{

    /**
     * Determine if the given user can view the toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function view(UserPolicy $user, Toppartner $toppartner)
    {
        if ($user->canDo('toppartner.toppartner.view') && $user->isAdmin()) {
            return true;
        }

        return $toppartner->user_id == user_id() && $toppartner->user_type == user_type();
    }

    /**
     * Determine if the given user can create a toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('toppartner.toppartner.create');
    }

    /**
     * Determine if the given user can update the given toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function update(UserPolicy $user, Toppartner $toppartner)
    {
        if ($user->canDo('toppartner.toppartner.edit') && $user->isAdmin()) {
            return true;
        }

        return $toppartner->user_id == user_id() && $toppartner->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Toppartner $toppartner)
    {
        return $toppartner->user_id == user_id() && $toppartner->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Toppartner $toppartner)
    {
        if ($user->canDo('toppartner.toppartner.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given toppartner.
     *
     * @param UserPolicy $user
     * @param Toppartner $toppartner
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Toppartner $toppartner)
    {
        if ($user->canDo('toppartner.toppartner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
