<?php

namespace Btravel\Toppartner\Providers;

use Illuminate\Support\ServiceProvider;

class ToppartnerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'toppartner');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'toppartner');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerToppartner();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerToppartner()
    {
        $this->app->bind('toppartner', function($app) {
            return new Toppartner($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Toppartner', 'Lavalite\Toppartner\Facades\Toppartner');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.toppartner', function ($app) {
            return $this->app->make('Btravel\Toppartner\Toppartner');
        });

                // Bind Toppartner to repository
        $this->app->bind(
            'Btravel\Toppartner\Interfaces\ToppartnerRepositoryInterface',
            \Btravel\Toppartner\Repositories\Eloquent\ToppartnerRepository::class
        );

        $this->app->register(\Btravel\Toppartner\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Toppartner\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and toppartner's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'btravel.toppartner'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeToppartner::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.toppartner'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/toppartner.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/toppartner')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/toppartner')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
